local type, ipairs, insert, UIParent, select = type, ipairs, table.insert, UIParent, select;

local TranslationTable = {
    ["Cancel"] = {
        ["deDE"] = "Abbrechen",
    },
}
local Translation = function(Text)
    if type(Text) == "string" then 
        if TranslationTable[Text] then 
            local Lang = GetLocale()
            if TranslationTable[Text][Lang] then 
                return TranslationTable[Text][Lang]
            else 
                return Text
            end 
        else 
            return Text.."NT"
        end 
    end 
end 


local function SetSelected(self, Value, UserInput)
    if type(Value) == "nil" then
        self.SelectDisplay.selectedText:SetText("")
        return nil;
    end
    if self.SelectListFunc then
        self.SelectList = self.SelectListFunc()
    end
    if self.SelectList then
        local NewIndex
        if type(Value) == "number" and self.SelectList[Value] then
            NewIndex = Value
        elseif type(Value) == "string" then
            for i, v in ipairs(self.SelectList) do
                if v == Value then
                    NewIndex = i
                    break
                end
            end
        end
        if not NewIndex then
            return nil
        end
        self.SelectDisplay.selectedText:SetText(self.SelectList[NewIndex],nil,"Normal")
        if self.OnSelect and UserInput then
            self.OnSelect(self, self.SelectList[NewIndex], NewIndex)
        end
    end
end

local function CallSelectList(self)
    if self.SelectListFunc then
        self.SelectList = self.SelectListFunc()
    end
    if self.SelectList then
        if self.SelectDropdownList then
            self.SelectDropdownList:Release()
            self.SelectDropdownList = nil
        else
            self.self:DropdownCall(self,self.SelectList,function(self,value,i)
                self:SetSelected(i, true)
                self:CallSelectList()            
            end)
        end
    end
end

function _Avyr_Global_ADDON_Elements_Lib.WidgetsMixin:CreateSelectbutton(Parent, SelectAlign)
    local Selectbutton = self:CreateFrame(Parent)

    Selectbutton.SelectAlign = SelectAlign

    Selectbutton.SelectDisplay = self:CreateButton(Selectbutton)
    Selectbutton.SelectDisplay:Size(nil, 20)
    Selectbutton.SelectDisplay:SetPoint("BOTTOMLEFT")
    Selectbutton.SelectDisplay:SetPoint("BOTTOMRIGHT")
    Selectbutton.SelectDisplay.OnClick = function(self)
        if not Selectbutton.Disable then
            CallSelectList(Selectbutton)
        end
    end

    Selectbutton.SelectDisplay:SetIcon("TexturePath",self:GetIcon("ArrowHeadMask"),"LockAspectRatio","RIGHT","Rotation",-45,"Theme","Highlight")

    Selectbutton.SelectDisplay.selectedText = self:CreateFrame(Selectbutton.SelectDisplay)
    Selectbutton.SelectDisplay.selectedText:SetText("", 11, 1, 1, 1, "LEFT","TOP")
    Selectbutton.SelectDisplay.selectedText:SetPoint("TOPLEFT")
    Selectbutton.SelectDisplay.selectedText:SetPoint("BOTTOMRIGHT",-20,0)


    Selectbutton.SetSelected = SetSelected
    Selectbutton.CallSelectList = CallSelectList

    return Selectbutton
end
